@@ -9,7 +9,7 @@ use Test::Pod::Snippets::Parser;
 use Module::Locate qw/ locate /;
 use Params::Validate qw/ validate_with validate /;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 #<<<
 my @parser_of   :Field :Get(parser);
@@ -34,6 +34,12 @@ my @do_functions :Field
                  :Get(is_extracting_functions)
                  :Set(extracts_functions)
                  ;
+
+my @preserve_lines :Field
+                   :Default(1)
+                   :Arg(preserve_lines)
+                   :Std(preserve_lines)
+                   ;
 #>>>
                  
 my @object_name  :Field :Default('$thingy') :Arg(object_name);
@@ -501,6 +507,12 @@ The name of the object (with the leading '$') to be
 used for the methods if the T:P:S object is set to 
 extract methods.
 
+=item preserve_lines => I<$boolean>
+
+If sets to true (which is the default), the generated code
+will be peppered with '#line' pre-compiler lines that will
+have any failing test point to the test's original file.
+
 =back
 
 =head2 is_extracting_verbatim
